/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.io;

import java.nio.channels.SelectionKey;

/**
 * Interface for a component that does I/O processing. This interface provides
 * the method through which a thread that handles I/O for multiple components
 * can trigger I/O processing for a specific components when one of its channels
 * has become ready.
 * 
 * @author Sebastian Marsching
 * 
 * @see CommunicationController
 */
public interface ChannelProcessor {

    /**
     * Performs I/O processing for this component. This method is called every
     * time one of the channels registered through the
     * {@link CommunicationController#registerChannel(ChannelProcessor, java.nio.channels.SelectableChannel)}
     * method becomes ready. The communication processor can define which events
     * it is interested in through the {@link SelectionKey} it gets when
     * registering a channel.
     */
    void processIO();

}
